
## [0.10.0] - 2018-02-15
 - Added: Allow MapType to be customized
 
## [0.9.0] - 2018-01-19
 - Added: Google Places Autocomplete
 
## [0.8.0] - 2018-01-12
 - Added: Django 2.0 support
 - Removed: python 2.7 support
 
## [0.7.0] - 2017-04-10
 - Added: Django 1.11 support (new widget rendering)
 - Removed: Django <= 1.10 support

## [0.6.0] - 2016-11-28
 - Added: Django 1.10 support
 - Removed: Django <= 1.7 support

## [0.5.0] - 2016-08-12
 - Added: Allow using Google Maps API Key
 - Changed: jquery version to 3.1.0

## [0.4.0] - 2016-07-05
 - Added: Python 3 Compatibility
 - Fixed: Adjusted widgets imports to maintain backwards compatibility 
 
## [0.3.0] - 2015-04-09
 - Added: Travis integration
 - Added: Django 1.7 & 1.8 support
 - Added: additional test coverage
 - Added: Map updates affecting geolocation now triggers change event on geolocation field
 - Changed: jquery version to 1.11.2

## [0.2.3] - 2013-10-08
 - Changed: Google Maps JS to always load over https
 
## [0.2.2] - 2012-12-13
 - Added: Django 1.4 support
 
## [0.2.1] - 2011-06-28
 - Added: `__eq__` method for GeoPt field to allow comparison 
 
## [0.2.0] - 2011-06-27 
 - Initial version

   
